@@ -7,15 +7,14 @@ $ #DISPLAYRequiresArg
 $ #WarnDisplaySet
 # ٹ: Ķѿ 'DISPLAY' ǤޤǤ\n
 $ #Usage
-# Blackbox %s: (c) 1997 - 2000 Brad Hughes\n\n\
+# Blackbox %s : (c) 2001 - 2002 Sean 'Shaleh' Perry\n\
+  \t\t\t 1997 - 2000, 2002 Brad Hughes\n\n\
   -display <string>\t\tǥץ쥤³\n\
   -rc <string>\t\t\tΥ꥽ե\n\
   -version\t\t\tСɽλ\n\
   -help\t\t\t\tΥإפɽλ\n\n
 $ #CompileOptions
 # ѥץ:\n\
-  Debugging\t\t\t%s\n\
-  Interlacing:\t\t\t%s\n\
+  ǥХå\t\t\t%s\n\
   Shape:\t\t\t%s\n\
-  Slit:\t\t\t\t%s\n\
-  8bpp Ordered Dithering:\t%s\n\n
+  8bpp ǥ:\t%s\n\n
